@@ -167,6 +167,7 @@ namespace clx {
 	class json_separator {
 	public:
 		typedef CharT char_type;
+		typedef std::basic_string<CharT, Traits> string_type;
 		
 		void reset() {}
 		
@@ -175,7 +176,6 @@ namespace clx {
 			if (next == last || (*next != ctrl.lbrace && *next != ctrl.quot)) return false;
 			else if (*next == ctrl.lbrace) ++next;
 			
-			key = Key();
 			while (next != last && *next != ctrl.colon) {
 				if (*next == ctrl.quot) {
 					if (!detail::next_string(next, last, key)) return false;
@@ -185,21 +185,25 @@ namespace clx {
 			}
 			++next;
 			
-			dest = Token();
+			string_type tmp;
 			while (next != last) {
-				if (*next == ctrl.comma || *next == ctrl.rbrace) return true;
+				if (*next == ctrl.comma || *next == ctrl.rbrace) {
+					if (!tmp.empty()) dest = lexical_cast<Token>(tmp);
+					return true;
+				}
 				else if (*next == ctrl.lbracket) {
-					if (!detail::next_member(next, last, dest, ctrl.lbracket, ctrl.rbracket)) break;
+					if (!detail::next_member(next, last, tmp, ctrl.lbracket, ctrl.rbracket)) break;
 				}
 				else if (*next == ctrl.lbrace) {
-					if (!detail::next_member(next, last, dest, ctrl.lbrace, ctrl.rbrace)) break;
+					if (!detail::next_member(next, last, tmp, ctrl.lbrace, ctrl.rbrace)) break;
 				}
 				else if (*next == ctrl.quot) {
-					if (!detail::next_string(next, last, dest)) break;
+					if (!detail::next_string(next, last, tmp)) break;
 				}
-				else if (!is_space()(*next)) dest += *next;
+				else if (!is_space()(*next)) tmp += *next;
 				++next;
 			}
+			
 			return false;
 		}
 		
