@@ -36,7 +36,7 @@
 #define CLX_WIN32_MUTEX_H
 
 #include <windows.h>
-#include "thread_error.h"
+#include "system_error.h"
 
 namespace clx {
 	template <class Mutex> class unique_lock;
@@ -52,7 +52,7 @@ namespace clx {
 		
 		basic_mutex() {
 			m_ = CreateMutex(NULL, false, NULL);
-			if (m_ == NULL) throw thread_error("CreateMutex");
+			if (m_ == NULL) throw system_error("CreateMutex");
 		}
 		
 		virtual ~basic_mutex() { CloseHandle(m_); }
